@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Pierre-Luc Beaudoin <pierre-luc@pierlux.com>
+ * Copyright (C) 2008-2009 Pierre-Luc Beaudoin <pierre-luc@pierlux.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,10 +28,17 @@
 
 #include <glib.h>
 
-#include <champlain/champlaindefines.h>
-#include <champlain/champlainview.h>
-#include <champlain/champlainmarker.h>
-#include <champlain/champlainlayer.h>
+#include "champlain/champlain-defines.h"
+#include "champlain/champlain-cache.h"
+#include "champlain/champlain-layer.h"
+#include "champlain/champlain-base-marker.h"
+#include "champlain/champlain-marker.h"
+#include "champlain/champlain-view.h"
+#include "champlain/champlain-enum-types.h"
+#include "champlain/champlain-map-source.h"
+#include "champlain/champlain-map-source-factory.h"
+#include "champlain/champlain-network-map-source.h"
+#include "champlain/champlain-version.h"
 
 #undef __CHAMPLAIN_CHAMPLAIN_H_INSIDE__
 
